Learn R Programming

vqtl (version 2.0.5)

c.scanonevar: c.scanonevar

Description

combines scanonevar objects that have permutations to improve the precision of the p-value estimates.

Usage

# S3 method for scanonevar
c(...)

Arguments

...

the scanonevar objects with permutations to be combined

Value

a scanonevar object that is the concatenation of the inputted scanonevars