Learn R Programming

vqtl (version 2.0.5)

scanonevar.perm: scanonevar.perm

Description

scanonevar.perm conducts many permuted forms of the scanonevar inputted, to assess the statistical significance of the results in the inputted scanonevar in a FWER-controlling manner.

Usage

scanonevar.perm(sov, n.perms, random.seed = 27599,
  n.cores = parallel::detectCores() - 2, silent = TRUE)

Arguments

sov

the scanonevar whose significance should be assessed empirically in an FWER-controlling method

n.perms

the number of permutations to do

random.seed

value to start the random number generator at, for reproducibility

n.cores

number of cores to use for the permutations

silent

Should all messaging be suppressed?

Value

27599

Examples

Run this code
# NOT RUN {
set.seed(27599)
test.cross <- qtl::sim.cross(map = qtl::sim.map(len = rep(20, 5), n.mar = 5), n.ind = 50)
scanonevar(cross = test.cross)

# }

Run the code above in your browser using DataLab